import 'dart:async';
import 'dart:convert';
import 'dart:io';

//import 'package:intl/intl.dart';
import 'package:mockito/mockito.dart';
import 'package:process/process.dart';
//import 'package:screenshots/src/base/context.dart';
//import 'package:screenshots/src/base/io.dart';
//import 'package:screenshots/src/base/process.dart';
import 'package:test/test.dart';

//import '../src/context.dart';
import '../src/mocks.dart';

class MockEchoProcess extends Mock implements Process {}

class MockProcessManager extends Mock implements ProcessManager {}

class MockStdIn extends Mock implements IOSink {}

class MockStream extends Mock implements Stream<List<int>> {}

class EchoClient {
  EchoClient(ProcessManager processManager) {
    _processManager = processManager;
  }

  final _cmd = ['fake command'];
  Process _process;
  ProcessManager _processManager;
  Completer _waitForResponse;

  String _msg;

  Future<void> get start async {
    _process = await _processManager.start(_cmd);
    _listen();
  }

  Future<String> echo(String msg) async {
    _waitForResponse = Completer<String>();
    _msg = await _waitForResponse.future;
    return _msg;
  }

  void _listen() {
    _process.stdout
        .transform<String>(utf8.decoder)
        .transform<String>(const LineSplitter())
        .listen((String line) async {
      print('<== $line');
      _waitForResponse.complete(line);
    });
  }
}

main() {
  group('in context', () {
//    MockStdio mockStdio;
//    MockProcessManager mockProcessManager;

    setUp(() {
//      mockProcessManager = MockProcessManager();
//      mockStdio = MockStdio();
    });

//    testUsingContext('echo from process', () async {
//      final PromptingProcess process = PromptingProcess();
//      mockProcessManager.processFactory = (List<String> commands) => process;
//      final Future<void> runPrompt =
//          process.showPrompt('Proceed (y/n)? ', <String>['hello', 'world']);
//      final Future<void> simulateUserInput = Future<void>(() {
//        mockStdio.simulateStdin('y');
//      });
//      await Future.wait<void>(<Future<void>>[runPrompt, simulateUserInput]);
//    }, overrides: <Type, Generator>{
//      ProcessManager: () => mockProcessManager,
//      Stdio: () => mockStdio,
//    });

//  testUsingContext('pub publish', () async {
//    final PromptingProcess process = PromptingProcess();
//    mockProcessManager.processFactory = (List<String> commands) => process;
//    final Future<void> runPackages = createTestCommandRunner(PackagesCommand())
//        .run(<String>['packages', 'pub', 'publish']);
//    final Future<void> runPrompt =
//        process.showPrompt('Proceed (y/n)? ', <String>['hello', 'world']);
//    final Future<void> simulateUserInput = Future<void>(() {
//      mockStdio.simulateStdin('y');
//    });
//    await Future.wait<void>(
//        <Future<void>>[runPackages, runPrompt, simulateUserInput]);
////    await Future.wait<void>(<Future<void>>[runPrompt, simulateUserInput]);
//    final List<String> commands = mockProcessManager.commands;
//    expect(commands, hasLength(2));
//    expect(commands[0], matches(r'dart-sdk[\\/]bin[\\/]pub'));
//    expect(commands[1], 'publish');
//    final List<String> stdout = mockStdio.writtenToStdout;
//    expect(stdout, hasLength(4));
//    expect(stdout.sublist(0, 2), contains('Proceed (y/n)? '));
//    expect(stdout.sublist(0, 2), contains('y\n'));
//    expect(stdout[2], 'hello\n');
//    expect(stdout[3], 'world\n');
//  }, overrides: <Type, Generator>{
//    ProcessManager: () => mockProcessManager,
//    Stdio: () => mockStdio,
//  });
  });

  group('not in context', () {
    test('run process', () async {
      final msg = 'hello';
      final mockProcess = MockEchoProcess();
      final mockProcessManager = MockProcessManager();
      final MockStdIn mockStdIn = MockStdIn();
      final MockStream mockStdErr = MockStream();

      when(mockProcessManager.start(any)).thenAnswer(
          (Invocation invocation) => Future<Process>.value(mockProcess));

      when(mockProcess.stdin).thenReturn(mockStdIn);
      when(mockProcess.stdout).thenAnswer((Invocation invocation) =>
          Stream<List<int>>.fromFuture(
              Future<List<int>>.value(utf8.encode(msg))));
      when(mockProcess.stderr)
          .thenAnswer((Invocation invocation) => mockStdErr);
      when(mockProcess.exitCode).thenAnswer((_) async => 0);

      final echoClient = EchoClient(mockProcessManager);
      await echoClient.start;
      final response = await echoClient.echo(msg);
      expect(response, msg);
    });
  });
}

//Future<void> _reject(
//  StreamController<List<int>> streamController,
////    ResidentCompiler generator,
//  MockStdIn mockFrontendServerStdIn,
//  String mockCompilerOutput,
//  String expected,
//) async {
//  // Put content into the output stream after generator.recompile gets
//  // going few lines below, resets completer.
//  scheduleMicrotask(() {
//    streamController.add(utf8.encode(mockCompilerOutput));
//  });
////  final CompilerOutput output = await generator.reject();
////  expect(output, isNull);
//  final String commands = mockFrontendServerStdIn.getAndClear();
//  final RegExp re = RegExp(expected);
//  expect(commands, matches(re));
//  mockFrontendServerStdIn._stdInWrites.clear();
//}

//class MockStdIn extends Mock implements IOSink {
//  final StringBuffer _stdInWrites = StringBuffer();
//
//  String getAndClear() {
//    final String result = _stdInWrites.toString();
//    _stdInWrites.clear();
//    return result;
//  }
//
//  @override
//  void write([Object o = '']) {
//    _stdInWrites.write(o);
//  }
//
//  @override
//  void writeln([Object o = '']) {
//    _stdInWrites.writeln(o);
//  }
//}

/// A process that prompts the user to proceed, then asynchronously writes
/// some lines to stdout before it exits.
class PromptingProcess implements Process {
  Future<void> showPrompt(String prompt, List<String> outputLines) async {
    _stdoutController.add(utf8.encode(prompt));
    final List<int> bytesOnStdin = await _stdin.future;
    // Echo stdin to stdout.
    _stdoutController.add(bytesOnStdin);
    if (bytesOnStdin[0] == utf8.encode('y')[0]) {
      for (final String line in outputLines) {
        _stdoutController.add(utf8.encode('$line\n'));
      }
    }
    await _stdoutController.close();
  }

  final StreamController<List<int>> _stdoutController =
      StreamController<List<int>>();
  final CompleterIOSink _stdin = CompleterIOSink();

  @override
  Stream<List<int>> get stdout => _stdoutController.stream;

  @override
  Stream<List<int>> get stderr => const Stream<List<int>>.empty();

  @override
  IOSink get stdin => _stdin;

  @override
  Future<int> get exitCode async {
    await _stdoutController.done;
    return 0;
  }

  @override
  dynamic noSuchMethod(Invocation invocation) => null;
}

/// An IOSink that completes a future with the first line written to it.
class CompleterIOSink extends MemoryIOSink {
  final Completer<List<int>> _completer = Completer<List<int>>();

  Future<List<int>> get future => _completer.future;

  @override
  void add(List<int> data) {
    if (!_completer.isCompleted) _completer.complete(data);
    super.add(data);
  }
}

//CommandRunner<void> createTestCommandRunner([FlutterCommand command]) {
//  final FlutterCommandRunner runner = FlutterCommandRunner();
//  if (command != null) runner.addCommand(command);
//  return runner;
//}
