import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:mockito/mockito.dart';
import 'package:process/process.dart';
//import 'package:screenshots/src/base/context.dart';
//import 'package:screenshots/src/base/io.dart';
//import 'package:screenshots/src/base/process.dart';
import 'package:test/test.dart';

class EchoClient {
  EchoClient(ProcessManager processManager) {
    _processManager = processManager;
  }

  final _start_echo_process = ['start echo process'];
  Process _echoProcess;
  ProcessManager _processManager;
  Completer _waitForResponse;
  Completer _waitForEvent = Completer<String>();

  Future<void> get start async {
    _echoProcess = await _processManager.start(_start_echo_process);
    _listen();
  }

  Future<String> echo(String msg) async {
    _sendMsg(msg);
    return await _response();
  }

  void _sendMsg(String msg) {
    print('==> $msg');
    _echoProcess.stdin.writeln(msg);
  }

  Future _response() async {
    _waitForResponse = Completer<String>();
    return await _waitForResponse.future;
  }

  Future<List> get emulators async {
    _sendMsg('get emulators');
    return jsonDecode(await _response());
  }

  Future<String> launchEmulator(String emulatorId) async {
    _sendMsg('launch emulator with id $emulatorId');
    _waitForResponse = Completer<String>();

    final results = await Future.wait(
        <Future>[_waitForResponse.future, _waitForEvent.future]);
    final event = results[1];
    final eventInfo = jsonDecode(event);
    print('eventInfo=$eventInfo');
    final deviceId = eventInfo[0]['deviceid'];
    print('deviceId=$deviceId');
    return deviceId;
  }

  void _listen() {
    _echoProcess.stdout
        .transform<String>(utf8.decoder)
        .transform<String>(const LineSplitter())
        .listen((String line) async {
      print('<== $line');

      // get event
      if (line.contains('event')) {
        _waitForEvent.complete(line);
        _waitForEvent = Completer<String>(); // enable wait for next event
      } else {
        // get response
        _waitForResponse.complete(line);
      }
    });
  }
}

main() {
  group('not in context', () {
    test('run process', () async {
      final mockProcess = MockEchoProcess();
      final mockProcessManager = MockProcessManager();
      final MockStdIn mockStdIn = MockStdIn();

      when(mockProcessManager.start(any)).thenAnswer(
          (Invocation invocation) => Future<Process>.value(mockProcess));
      when(mockProcess.stdin).thenReturn(mockStdIn);
//      when(mockProcess.stderr)
//          .thenAnswer((Invocation invocation) => mockStdErr);
//      when(mockProcess.exitCode).thenAnswer((_) async => 0);

      final msg = 'hello';
//      when(mockProcess.stdout).thenAnswer((Invocation invocation) =>
//          Stream<List<int>>.fromFuture(
//              Future<List<int>>.value(utf8.encode(msg))));
      when(mockProcess.stdout).thenAnswer((Invocation invocation) {
        return Stream<List<int>>.periodic(
            Duration(milliseconds: 0), getNextLine);
      });
      final echoClient = EchoClient(mockProcessManager);
      await echoClient.start;
      final response = await echoClient.echo(msg);
      expect(response, msg);

      final expectedEmulators = ['emulators'];

//      await echoClient.start;
      final responseList = await echoClient.emulators;
      expect(responseList, expectedEmulators);

      final emulatorId = 'emulator id';
      final expectedDeviceId = 'device id';
      final deviceId = await echoClient.launchEmulator(emulatorId);
      expect(deviceId, expectedDeviceId);
    });
  });
}

class MockEchoProcess extends Mock implements Process {}

class MockProcessManager extends Mock implements ProcessManager {}

class MockStdIn extends Mock implements IOSink {}

class MockStream extends Mock implements Stream<List<int>> {}

List<int> getNextLine(int i) {
  final lines = <List<int>>[
    utf8.encode('hello\n'),
    utf8.encode('["emulators"]\n'),
    utf8.encode('Starting device using emulator id...\n'),
    utf8.encode('[{"event":"emulator.started","deviceid":"device id"}]\n'),
  ];
  return lines[i];
}
